{
    "$graph": [
        {
            "class": "Workflow",
            "label": "scatter GATK HaplotypeCaller over intervals",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#main/emit_reference_confidence/NONE",
                            "#main/emit_reference_confidence/BP_RESOLUTION",
                            "#main/emit_reference_confidence/GVCF"
                        ]
                    },
                    "id": "#main/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#main/intervals"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#main/haplotype_caller/intervals"
                    ],
                    "run": "#gatk_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/haplotype_caller/bam"
                        },
                        {
                            "source": "#main/contamination_fraction",
                            "id": "#main/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/haplotype_caller/dbsnp_vcf"
                        },
                        {
                            "source": "#main/emit_reference_confidence",
                            "id": "#main/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#main/gvcf_gq_bands",
                            "id": "#main/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/haplotype_caller/intervals"
                        },
                        {
                            "valueFrom": "${ if (inputs.intervals.length == 1 && inputs.intervals[0].match(/^[0-9A-Za-z]+$/)) { return inputs.intervals[0] + \".g.vcf.gz\"; } else { return \"output.g.vcf.gz\"; } }",
                            "id": "#main/haplotype_caller/output_file_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#main/haplotype_caller/gvcf"
                    ],
                    "id": "#main/haplotype_caller"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/haplotype_caller/gvcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/gvcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.5.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-contamination",
                        "position": 7
                    },
                    "id": "#gatk_haplotype_caller.cwl/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/dbsnp_vcf"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/NONE",
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/BP_RESOLUTION",
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/GVCF"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-ERC",
                        "position": 3
                    },
                    "id": "#gatk_haplotype_caller.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GQB"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#gatk_haplotype_caller.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#gatk_haplotype_caller.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "maximum number of alternate alleles to genotype",
                    "inputBinding": {
                        "prefix": "--max_alternate_alleles",
                        "position": 8
                    },
                    "id": "#gatk_haplotype_caller.cwl/max_alternate_alleles"
                },
                {
                    "type": "string",
                    "default": "output.g.vcf.gz",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 12
                    },
                    "id": "#gatk_haplotype_caller.cwl/output_file_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "filters to apply to reads before analysis",
                    "inputBinding": {
                        "prefix": "--read_filter",
                        "position": 11
                    },
                    "id": "#gatk_haplotype_caller.cwl/read_filter"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_haplotype_caller.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "parameter to pass to the index creator",
                    "inputBinding": {
                        "prefix": "--variant_index_parameter",
                        "position": 10
                    },
                    "id": "#gatk_haplotype_caller.cwl/variant_index_parameter"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#gatk_haplotype_caller.cwl/variant_index_type/DYNAMIC_SEEK",
                                "#gatk_haplotype_caller.cwl/variant_index_type/DYNAMIC_SIZE",
                                "#gatk_haplotype_caller.cwl/variant_index_type/LINEAR",
                                "#gatk_haplotype_caller.cwl/variant_index_type/INTERVAL"
                            ]
                        }
                    ],
                    "doc": "type of IndexCreator to use for VCF/BCF indices",
                    "inputBinding": {
                        "prefix": "--variant_index_type",
                        "position": 9
                    },
                    "id": "#gatk_haplotype_caller.cwl/variant_index_type"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_name)"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/gvcf"
                }
            ],
            "id": "#gatk_haplotype_caller.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
